@@ -23,6 +23,15 @@ sub shell_is_okay
     return $? == 0;
   }
   
+  if($shell eq 'jsh' && -x $full_path)
+  {
+    require IPC::Open3;
+    my $pid = IPC::Open3::open3(\*IN, \*OUT, \*ERR, $full_path, '-c' => 'exit 22');
+    waitpid $pid, 0;
+    while(<ERR>) { note $_ }
+    return $? >> 8 == 22;
+  }
+
   return 1 if -x $full_path;
 }
 
